OverlayOps

Struct OverlayOps 

pub struct OverlayOps {
    pub additions: Vec<PlanOp>,
    pub removals: Vec<PlanOp>,
}
Overlay operations, split at the point crate::compose::splice needs.

Fields

additions: Vec<PlanOp>

Creations, moves and updates. Spliced after the shared additions, so they may target a channel that was created in the same turn.

removals: Vec<PlanOp>

Withdrawals. Spliced before the shared removals, so they vacate a channel that is about to die.

Implementations