pub struct UserPatch {
pub session: SessionId,
pub name: Option<String>,
pub flags: Option<UserFlags>,
}Expand description
A sparse user change. The channel move is a separate operation, because it has to be ordered before any channel removal.
Fields
session: SessionIdname: Option<String>flags: Option<UserFlags>Implementations