pub struct Spoken {
pub from: Option<ConnectionId>,
pub to: Audience,
pub text: String,
}Expand description
One message a flavor asked to have delivered to an audience.
Fields
from: Option<ConnectionId>Who it is attributed to. None means the server itself, which is what
makes the client label it as coming from the server rather than a user.
to: Audiencetext: StringTrait Implementations
impl Eq for Spoken
impl StructuralPartialEq for Spoken