pub struct AttachedConnection { /* private fields */ }Expand description
One connection attached to a shard, and its committed state.
Implementations
Sourceimpl AttachedConnection
impl AttachedConnection
pub fn id(&self) -> ConnectionId
pub fn session(&self) -> SessionId
pub fn cursor(&self) -> u64
pub fn observation(&self) -> ScopeSet
Sourcepub fn overlay_sent(&self) -> &Overlay
pub fn overlay_sent(&self) -> &Overlay
The private elements this connection has actually received.
Sourcepub fn actions_sent(&self) -> &Actions
pub fn actions_sent(&self) -> &Actions
The context actions this connection has actually been offered.
Sourcepub fn must_close(&self) -> bool
pub fn must_close(&self) -> bool
Whether the queue has refused something unrecoverable.
The cursor cell the voice plane gates on.